Documentation
¶
Overview ¶
Package v1alpha1 contains API Schema definitions for the interview v1alpha1 API group +kubebuilder:object:generate=true +groupName=interview.com
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // GroupVersion is group version used to register these objects GroupVersion = schema.GroupVersion{Group: "interview.com", Version: "v1alpha1"} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: GroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
Functions ¶
This section is empty.
Types ¶
type Dummy ¶
type Dummy struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec DummySpec `json:"spec,omitempty"`
Status DummyStatus `json:"status,omitempty"`
}
Dummy is the Schema for the dummies API
func (*Dummy) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Dummy.
func (*Dummy) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Dummy) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type DummyList ¶
type DummyList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []Dummy `json:"items"`
}
DummyList contains a list of Dummy
func (*DummyList) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DummyList.
func (*DummyList) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*DummyList) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type DummySpec ¶
type DummySpec struct {
//+kubebuilder:validation:MinLength=1
// Message is the message to be printed by the dummy operator
Message string `json:"message,omitempty"`
}
DummySpec defines the desired state of Dummy
func (*DummySpec) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DummySpec.
func (*DummySpec) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type DummyStatus ¶
type DummyStatus struct {
// INSERT ADDITIONAL STATUS FIELD - define observed state of cluster
// Important: Run "make" to regenerate code after modifying this file
SpecEcho string `json:"specEcho,omitempty"`
// status of the nginx pod managed by the dummy resource
PodStatus string `json:"podStatus,omitempty"`
}
DummyStatus defines the observed state of Dummy
func (*DummyStatus) DeepCopy ¶
func (in *DummyStatus) DeepCopy() *DummyStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DummyStatus.
func (*DummyStatus) DeepCopyInto ¶
func (in *DummyStatus) DeepCopyInto(out *DummyStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.